@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 require XSLoader;
 XSLoader::load('Colouring::In::XS', $VERSION);
@@ -47,7 +47,7 @@ Colouring::In::XS - color or colour.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -342,16 +342,12 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-=over 4
+=over 2
 
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Colouring-In-XS>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Colouring-In-XS>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/Colouring-In-XS>
@@ -362,7 +358,7 @@ L<https://metacpan.org/release/Colouring-In-XS>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2024 by LNATION.
+This software is Copyright (c) 2024->2025 by LNATION.
 
 This is free software, licensed under:
 
